BEARD_TOKEN_SYMBOL = "BEARD"

BEARD_TOKEN_POLICY_ID = "8d7526784ef72fe0ccdd085976ada0da88e7fb013e38e794b0923341"
BEARD_TOKEN_ASSET_NAME = "4245415244"

BEARD_TOKEN_ASSET_ID = f"{BEARD_TOKEN_POLICY_ID}{BEARD_TOKEN_ASSET_NAME}"

BEARD_TOKEN_FINGERPRINT = "asset1kkuscpr9fg4r038te6ue93eskht76gmylmsav9"
