CHARLES_TOKEN_SYMBOL = "CHARLES"

CHARLES_TOKEN_POLICY_ID = "c8c711a3df70956c397cb92e1705b675b18652723cfb7f72ccd59f2d"
CHARLES_TOKEN_ASSET_NAME = "434841524c4553"

CHARLES_TOKEN_ASSET_ID = f"{CHARLES_TOKEN_POLICY_ID}{CHARLES_TOKEN_ASSET_NAME}"

CHARLES_TOKEN_FINGERPRINT = "asset1849ky50sq5gudwfn368dznzqpwfrsq7q5fvw2y"
